/*
 *   Copyright 2010 Brian Rosenberger (Brutex Network)
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
package net.brutex.xservices.ws;

import javax.jws.WebMethod;
import javax.jws.WebParam;
import javax.jws.WebService;
import net.brutex.xservices.types.FileSetResource;
import net.brutex.xservices.types.HostConnection;
import net.brutex.xservices.types.MailMimeType;
import net.brutex.xservices.types.ReturnCode;
import net.brutex.xservices.util.BrutexNamespaces;
import org.apache.cxf.annotations.WSDLDocumentation;

/**
 *
 * @author Brian Rosenberger, bru@brutex.de
 */
@WebService(targetNamespace = BrutexNamespaces.WS_XSERVICES)
public interface MiscService {

    
    
    /**
     * @param hostname
     * @return
     */
    @WebMethod(operationName = "getHostinfo")
    public ReturnCode getHostinfo(@WebParam(name = "hostname") String hostname);

    /**
     *
     * @param mailhost
     * @param from
     * @param tolist
     * @param subject
     * @param message
     * @return
     */
    @WebMethod(operationName = "sendMailSimple")
    public ReturnCode sendMailSimple(@WebParam(name = "mailhost") HostConnection mailhost,
            @WebParam(name = "from") String from,
            @WebParam(name = "to") String tolist,
            @WebParam(name = "subject") String subject,
            @WebParam(name = "message") String message);

    /**
     *
     * @param mailhost
     * @param from
     * @param tolist
     * @param subject
     * @param message
     * @param res
     * @return
     */
    @WebMethod(operationName = "sendMailSimpleWithAttachment")
    public ReturnCode sendMailSimpleWithAttachment(@WebParam(name = "mailhost") HostConnection mailhost,
            @WebParam(name = "from") String from,
            @WebParam(name = "to") String tolist,
            @WebParam(name = "subject") String subject,
            @WebParam(name = "message") String message,
            @WebParam(name = "attachments") FileSetResource res);

    /**
     *
     * @param mailhost
     * @param from
     * @param tolist
     * @param cclist
     * @param bcclist
     * @param subject
     * @param mimetype
     * @param charset
     * @param message
     * @param res
     * @param ssl
     * @param tls
     * @return
     */
    @WebMethod(operationName = "sendMail")
    public ReturnCode sendMail(@WebParam(name = "mailhost") HostConnection mailhost,
            @WebParam(name = "from") String from,
            @WebParam(name = "to") String tolist,
            @WebParam(name = "cc") String cclist,
            @WebParam(name = "bcc") String bcclist,
            @WebParam(name = "subject") String subject,
            @WebParam(name = "mimetype") MailMimeType mimetype,
            @WebParam(name = "charset") String charset,
            @WebParam(name = "message") String message,
            @WebParam(name = "attachments") FileSetResource res,
            @WebParam(name = "useSSL") boolean ssl,
            @WebParam(name = "useStartTLS") boolean tls);

    /**
     *
     * @param minutes
     * @param seconds
     * @return
     */
    @WebMethod(operationName = "sleep")
    public ReturnCode sleep(@WebParam(name = "minutes") int minutes,
            @WebParam(name = "seconds") int seconds);
}
